@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
  /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -38,14 +39,13 @@
 #endif // #if (OSL_DEBUG_LEVEL > 1) && defined TEST_MIB
 #include <tools/debug.hxx>
 #include <vcl/window.hxx>
-#include <errhdl.hxx>
 #include <swtypes.hxx>
 
 #include <com/sun/star/accessibility/XAccessible.hpp>
 #include <com/sun/star/accessibility/XAccessibleStateSet.hpp>
 #include <com/sun/star/accessibility/AccessibleStateType.hpp>
 #include <com/sun/star/accessibility/AccessibleEventId.hpp>
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
 #include <vcl/svapp.hxx>
 #include <unotools/accessiblestatesethelper.hxx>
 #include <unotools/accessiblerelationsethelper.hxx>
@@ -105,7 +105,7 @@ void SwAccessibleContext::InitStates()
 
 void SwAccessibleContext::SetParent( SwAccessibleContext *pParent )
 {
-    vos::OGuard aGuard( aMutex );
+    osl::MutexGuard aGuard( aMutex );
 
     uno::Reference < XAccessible > xParent( pParent );
     xWeakParent = xParent;
@@ -113,7 +113,7 @@ void SwAccessibleContext::SetParent( SwAccessibleContext *pParent )
 
 uno::Reference< XAccessible > SwAccessibleContext::GetWeakParent() const
 {
-    vos::OGuard aGuard( aMutex );
+    osl::MutexGuard aGuard( aMutex );
 
     uno::Reference< XAccessible > xParent( xWeakParent );
     return xParent;
@@ -126,11 +126,11 @@ Window *SwAccessibleContext::GetWindow()
     if( GetMap() )
     {
         const ViewShell *pVSh = GetMap()->GetShell();
-        ASSERT( pVSh, "no view shell" );
+        OSL_ENSURE( pVSh, "no view shell" );
         if( pVSh )
             pWin = pVSh->GetWin();
 
-        ASSERT( pWin, "no window" );
+        OSL_ENSURE( pWin, "no window" );
     }
 
     return pWin;
@@ -141,7 +141,7 @@ SwCrsrShell* SwAccessibleContext::GetCrsrShell()
 {
     SwCrsrShell* pCrsrShell;
     ViewShell* pViewShell = GetMap() ? GetMap()->GetShell() : 0;
-    ASSERT( pViewShell, "no view shell" );
+    OSL_ENSURE( pViewShell, "no view shell" );
     if( pViewShell && pViewShell->ISA( SwCrsrShell ) )
         pCrsrShell = static_cast<SwCrsrShell*>( pViewShell );
     else
@@ -155,7 +155,7 @@ const SwCrsrShell* SwAccessibleContext::GetCrsrShell() const
     // just like non-const GetCrsrShell
     const SwCrsrShell* pCrsrShell;
     const ViewShell* pViewShell = GetMap() ? GetMap()->GetShell() : 0;
-    ASSERT( pViewShell, "no view shell" );
+    OSL_ENSURE( pViewShell, "no view shell" );
     if( pViewShell && pViewShell->ISA( SwCrsrShell ) )
         pCrsrShell = static_cast<const SwCrsrShell*>( pViewShell );
     else
@@ -225,13 +225,13 @@ void SwAccessibleContext::ChildrenScrolled( const SwFrm *pFrm,
             {
                 if ( rLower.GetSwFrm() )
                 {
-                    ASSERT( !rLower.AlwaysIncludeAsChild(),
+                    OSL_ENSURE( !rLower.AlwaysIncludeAsChild(),
                             "<SwAccessibleContext::ChildrenScrolled(..)> - always included child not considered!" );
                     const SwFrm* pLower( rLower.GetSwFrm() );
-                    ::vos::ORef< SwAccessibleContext > xAccImpl =
+                    ::rtl::Reference< SwAccessibleContext > xAccImpl =
                         GetMap()->GetContextImpl( pLower, SCROLLED_OUT == eAction ||
                                                 SCROLLED_IN == eAction );
-                    if( xAccImpl.isValid() )
+                    if( xAccImpl.is() )
                     {
                         switch( eAction )
                         {
@@ -258,14 +258,14 @@ void SwAccessibleContext::ChildrenScrolled( const SwFrm *pFrm,
                 }
                 else if ( rLower.GetDrawObject() )
                 {
-                    ASSERT( !rLower.AlwaysIncludeAsChild(),
+                    OSL_ENSURE( !rLower.AlwaysIncludeAsChild(),
                             "<SwAccessibleContext::ChildrenScrolled(..)> - always included child not considered!" );
-                    ::vos::ORef< ::accessibility::AccessibleShape > xAccImpl =
+                    ::rtl::Reference< ::accessibility::AccessibleShape > xAccImpl =
                         GetMap()->GetContextImpl( rLower.GetDrawObject(),
                                                   this,
                                                   SCROLLED_OUT == eAction ||
                                                   SCROLLED_IN == eAction );
-                    if( xAccImpl.isValid() )
+                    if( xAccImpl.is() )
                     {
                         switch( eAction )
                         {
@@ -277,7 +277,7 @@ void SwAccessibleContext::ChildrenScrolled( const SwFrm *pFrm,
                             break;
                         case SCROLLED_IN:
                             ScrolledInShape( rLower.GetDrawObject(),
-                                             xAccImpl.getBodyPtr() );
+                                             xAccImpl.get() );
                             break;
                         case SCROLLED_OUT:
                             {
@@ -285,7 +285,7 @@ void SwAccessibleContext::ChildrenScrolled( const SwFrm *pFrm,
                                     ::accessibility::IAccessibleViewForwarderListener::VISIBLE_AREA,
                                     GetMap() );
                                 DisposeShape( rLower.GetDrawObject(),
-                                              xAccImpl.getBodyPtr() );
+                                              xAccImpl.get() );
                             }
                             break;
                         case NONE:
@@ -296,7 +296,7 @@ void SwAccessibleContext::ChildrenScrolled( const SwFrm *pFrm,
                 else if ( rLower.GetWindow() )
                 {
                     // nothing to do - as such children are always included as children.
-                    ASSERT( rLower.AlwaysIncludeAsChild(),
+                    OSL_ENSURE( rLower.AlwaysIncludeAsChild(),
                             "<SwAccessibleContext::ChildrenScrolled(..)> - not always included child not considered!" );
                 }
             }
@@ -322,7 +322,7 @@ void SwAccessibleContext::Scrolled( const SwRect& rOldVisArea )
     sal_Bool bIsOldShowingState;
     sal_Bool bIsNewShowingState = IsShowing( *(GetMap()) );
     {
-        vos::OGuard aGuard( aMutex );
+        osl::MutexGuard aGuard( aMutex );
         bIsOldShowingState = bIsShowingState;
         bIsShowingState = bIsNewShowingState;
     }
@@ -346,24 +346,24 @@ void SwAccessibleContext::ScrolledIn()
     // This accessible should be freshly created, because it
     // was not visisble before. Therefor, its vis area must already
     // reflect the scrolling.
-    ASSERT( GetVisArea() == GetMap()->GetVisArea(),
+    OSL_ENSURE( GetVisArea() == GetMap()->GetVisArea(),
             "Vis area of child is wrong. Did it exist already?" );
 
     // Send child event at parent. That's all we have to do here.
     const SwFrm* pParent = GetParent();
-    ::vos::ORef< SwAccessibleContext > xParentImpl(
+    ::rtl::Reference< SwAccessibleContext > xParentImpl(
          GetMap()->GetContextImpl( pParent, sal_False ) );
     uno::Reference < XAccessibleContext > xThis( this );
-    if( xParentImpl.isValid() )
+    if( xParentImpl.is() )
     {
-        SetParent( xParentImpl.getBodyPtr() );
+        SetParent( xParentImpl.get() );
 
         AccessibleEventObject aEvent;
         aEvent.EventId = AccessibleEventId::CHILD;
         aEvent.NewValue <<= xThis;
 
         xParentImpl->FireAccessibleEvent( aEvent );
-        DBG_MSG_PARAM( "AccessibleChild (added)", xChildImpl.getBodyPtr() );
+        DBG_MSG_PARAM( "AccessibleChild (added)", xChildImpl.get() );
 
         if( HasCursor() )
         {
@@ -398,7 +398,7 @@ void SwAccessibleContext::ScrolledOut( const SwRect& rOldVisArea )
     Dispose( sal_True );
 }
 
-// --> OD 2005-12-12 #i27301# - use new type definition for <_nStates>
+// #i27301# - use new type definition for <_nStates>
 void SwAccessibleContext::InvalidateChildrenStates( const SwFrm* _pFrm,
                                                     tAccessibleStates _nStates )
 {
@@ -411,10 +411,10 @@ void SwAccessibleContext::InvalidateChildrenStates( const SwFrm* _pFrm,
         const SwFrm* pLower = rLower.GetSwFrm();
         if( pLower )
         {
-            ::vos::ORef< SwAccessibleContext > xAccImpl;
+            ::rtl::Reference< SwAccessibleContext > xAccImpl;
             if( rLower.IsAccessible( GetShell()->IsPreView() ) )
                 xAccImpl = GetMap()->GetContextImpl( pLower, sal_False );
-            if( xAccImpl.isValid() )
+            if( xAccImpl.is() )
                 xAccImpl->InvalidateStates( _nStates );
             else
                 InvalidateChildrenStates( pLower, _nStates );
@@ -444,21 +444,21 @@ void SwAccessibleContext::DisposeChildren( const SwFrm *pFrm,
         const SwFrm* pLower = rLower.GetSwFrm();
         if( pLower )
         {
-            ::vos::ORef< SwAccessibleContext > xAccImpl;
+            ::rtl::Reference< SwAccessibleContext > xAccImpl;
             if( rLower.IsAccessible( GetShell()->IsPreView() ) )
                 xAccImpl = GetMap()->GetContextImpl( pLower, sal_False );
-            if( xAccImpl.isValid() )
+            if( xAccImpl.is() )
                 xAccImpl->Dispose( bRecursive );
             else if( bRecursive )
                 DisposeChildren( pLower, bRecursive );
         }
         else if ( rLower.GetDrawObject() )
         {
-            ::vos::ORef< ::accessibility::AccessibleShape > xAccImpl(
+            ::rtl::Reference< ::accessibility::AccessibleShape > xAccImpl(
                     GetMap()->GetContextImpl( rLower.GetDrawObject(),
                                           this, sal_False )  );
-            if( xAccImpl.isValid() )
-                DisposeShape( rLower.GetDrawObject(), xAccImpl.getBodyPtr() );
+            if( xAccImpl.is() )
+                DisposeShape( rLower.GetDrawObject(), xAccImpl.get() );
         }
         else if ( rLower.GetWindow() )
         {
@@ -482,7 +482,7 @@ void SwAccessibleContext::_InvalidateFocus()
 
 void SwAccessibleContext::FireAccessibleEvent( AccessibleEventObject& rEvent )
 {
-    ASSERT( GetFrm(), "fire event for diposed frame?" );
+    OSL_ENSURE( GetFrm(), "fire event for diposed frame?" );
     if( !GetFrm() )
         return;
 
@@ -523,7 +523,7 @@ void SwAccessibleContext::FireStateChangedEvent( sal_Int16 nState,
 void SwAccessibleContext::GetStates(
         ::utl::AccessibleStateSetHelper& rStateSet )
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
 
     // SHOWING
     if( bIsShowingState )
@@ -551,7 +551,7 @@ sal_Bool SwAccessibleContext::IsEditableState()
 {
     sal_Bool bRet;
     {
-        vos::OGuard aGuard( aMutex );
+        osl::MutexGuard aGuard( aMutex );
         bRet = bIsEditableState;
     }
 
@@ -575,7 +575,7 @@ SwAccessibleContext::SwAccessibleContext( SwAccessibleMap *pM,
 
 SwAccessibleContext::~SwAccessibleContext()
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
 
     DBG_MSG_CD( "destructed" )
     RemoveFrmFromAccessibleMap();
@@ -592,7 +592,7 @@ uno::Reference< XAccessibleContext > SAL_CALL
 sal_Int32 SAL_CALL SwAccessibleContext::getAccessibleChildCount( void )
         throw (uno::RuntimeException)
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
 
     CHECK_FOR_DEFUNC( XAccessibleContext )
 
@@ -603,7 +603,7 @@ uno::Reference< XAccessible> SAL_CALL
     SwAccessibleContext::getAccessibleChild( sal_Int32 nIndex )
         throw (uno::RuntimeException, lang::IndexOutOfBoundsException)
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
 
     CHECK_FOR_DEFUNC( XAccessibleContext )
 
@@ -620,21 +620,21 @@ uno::Reference< XAccessible> SAL_CALL
     uno::Reference< XAccessible > xChild;
     if( aChild.GetSwFrm() )
     {
-        ::vos::ORef < SwAccessibleContext > xChildImpl(
+        ::rtl::Reference < SwAccessibleContext > xChildImpl(
                 GetMap()->GetContextImpl( aChild.GetSwFrm(), !bDisposing )  );
-        if( xChildImpl.isValid() )
+        if( xChildImpl.is() )
         {
             xChildImpl->SetParent( this );
-            xChild = xChildImpl.getBodyPtr();
+            xChild = xChildImpl.get();
         }
     }
     else if ( aChild.GetDrawObject() )
     {
-        ::vos::ORef < ::accessibility::AccessibleShape > xChildImpl(
+        ::rtl::Reference < ::accessibility::AccessibleShape > xChildImpl(
                 GetMap()->GetContextImpl( aChild.GetDrawObject(),
                                           this, !bDisposing )  );
-        if( xChildImpl.isValid() )
-            xChild = xChildImpl.getBodyPtr();
+        if( xChildImpl.is() )
+            xChild = xChildImpl.get();
     }
     else if ( aChild.GetWindow() )
     {
@@ -647,22 +647,22 @@ uno::Reference< XAccessible> SAL_CALL
 uno::Reference< XAccessible> SAL_CALL SwAccessibleContext::getAccessibleParent (void)
         throw (uno::RuntimeException)
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
 
     CHECK_FOR_DEFUNC( XAccessibleContext )
 
     const SwFrm *pUpper = GetParent();
-    ASSERT( pUpper != 0 || bDisposing, "no upper found" );
+    OSL_ENSURE( pUpper != 0 || bDisposing, "no upper found" );
 
     uno::Reference< XAccessible > xAcc;
     if( pUpper )
         xAcc = GetMap()->GetContext( pUpper, !bDisposing );
 
-    ASSERT( xAcc.is() || bDisposing, "no parent found" );
+    OSL_ENSURE( xAcc.is() || bDisposing, "no parent found" );
 
     // Remember the parent as weak ref.
     {
-        vos::OGuard aWeakParentGuard( aMutex );
+        osl::MutexGuard aWeakParentGuard( aMutex );
         xWeakParent = xAcc;
     }
 
@@ -672,20 +672,20 @@ uno::Reference< XAccessible> SAL_CALL SwAccessibleContext::getAccessibleParent (
 sal_Int32 SAL_CALL SwAccessibleContext::getAccessibleIndexInParent (void)
         throw (uno::RuntimeException)
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
 
     CHECK_FOR_DEFUNC( XAccessibleContext )
 
     const SwFrm *pUpper = GetParent();
-    ASSERT( pUpper != 0 || bDisposing, "no upper found" );
+    OSL_ENSURE( pUpper != 0 || bDisposing, "no upper found" );
 
     sal_Int32 nIndex = -1;
     if( pUpper )
     {
-        ::vos::ORef < SwAccessibleContext > xAccImpl(
+        ::rtl::Reference < SwAccessibleContext > xAccImpl(
             GetMap()->GetContextImpl( pUpper, !bDisposing )  );
-        ASSERT( xAccImpl.isValid() || bDisposing, "no parent found" );
-        if( xAccImpl.isValid() )
+        OSL_ENSURE( xAccImpl.is() || bDisposing, "no parent found" );
+        if( xAccImpl.is() )
             nIndex = xAccImpl->GetChildIndex( *(GetMap()), SwAccessibleChild(GetFrm()) );
     }
 
@@ -701,7 +701,7 @@ sal_Int16 SAL_CALL SwAccessibleContext::getAccessibleRole (void)
 OUString SAL_CALL SwAccessibleContext::getAccessibleDescription (void)
         throw (uno::RuntimeException)
 {
-    ASSERT( !this, "description needs to be overloaded" );
+    OSL_ENSURE( !this, "description needs to be overloaded" );
     THROW_RUNTIME_EXCEPTION( XAccessibleContext, "internal error (method must be overloaded)" );
 }
 
@@ -724,7 +724,7 @@ uno::Reference<XAccessibleStateSet> SAL_CALL
     SwAccessibleContext::getAccessibleStateSet (void)
         throw (uno::RuntimeException)
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
 
     CHECK_FOR_DEFUNC( XAccessibleContext )
 
@@ -740,7 +740,7 @@ uno::Reference<XAccessibleStateSet> SAL_CALL
 lang::Locale SAL_CALL SwAccessibleContext::getLocale (void)
         throw (IllegalAccessibleComponentStateException, uno::RuntimeException)
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
 
     lang::Locale aLoc( Application::GetSettings().GetLocale() );
     return aLoc;
@@ -754,7 +754,7 @@ void SAL_CALL SwAccessibleContext::addEventListener(
 
     if (xListener.is())
     {
-        vos::OGuard aGuard(Application::GetSolarMutex());
+        SolarMutexGuard aGuard;
         if (!nClientId)
             nClientId = comphelper::AccessibleEventNotifier::registerClient( );
         comphelper::AccessibleEventNotifier::addEventListener( nClientId, xListener );
@@ -769,7 +769,7 @@ void SAL_CALL SwAccessibleContext::removeEventListener(
 
     if (xListener.is())
     {
-        vos::OGuard aGuard(Application::GetSolarMutex());
+        SolarMutexGuard aGuard;
         sal_Int32 nListenerCount = comphelper::AccessibleEventNotifier::removeEventListener( nClientId, xListener );
         if ( !nListenerCount )
         {
@@ -810,7 +810,7 @@ uno::Reference< XAccessible > SAL_CALL SwAccessibleContext::getAccessibleAtPoint
                 const awt::Point& aPoint )
         throw (uno::RuntimeException)
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
 
     CHECK_FOR_DEFUNC( XAccessibleComponent )
 
@@ -867,12 +867,12 @@ uno::Reference< XAccessible > SAL_CALL SwAccessibleContext::getAccessibleAtPoint
 awt::Rectangle SAL_CALL SwAccessibleContext::getBoundsImpl(sal_Bool bRelative)
         throw (uno::RuntimeException)
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
 
     CHECK_FOR_DEFUNC( XAccessibleComponent )
 
     const SwFrm *pParent = GetParent();
-    ASSERT( pParent, "no Parent found" );
+    OSL_ENSURE( pParent, "no Parent found" );
     Window *pWin = GetWindow();
 
     CHECK_FOR_WINDOW( XAccessibleComponent, pWin && pParent )
@@ -882,10 +882,10 @@ awt::Rectangle SAL_CALL SwAccessibleContext::getBoundsImpl(sal_Bool bRelative)
     if( GetFrm()->IsPageFrm() &&
         static_cast < const SwPageFrm * >( GetFrm() )->IsEmptyPage() )
     {
-        ASSERT( GetShell()->IsPreView(), "empty page accessible?" );
+        OSL_ENSURE( GetShell()->IsPreView(), "empty page accessible?" );
         if( GetShell()->IsPreView() )
         {
-            // OD 15.01.2003 #103492# - adjust method call <GetMap()->GetPreViewPageSize()>
+            // adjust method call <GetMap()->GetPreViewPageSize()>
             sal_uInt16 nPageNum =
                 static_cast < const SwPageFrm * >( GetFrm() )->GetPhyPageNum();
             aLogBounds.SSize( GetMap()->GetPreViewPageSize( nPageNum ) );
@@ -953,7 +953,7 @@ awt::Size SAL_CALL SwAccessibleContext::getSize()
 void SAL_CALL SwAccessibleContext::grabFocus()
         throw (uno::RuntimeException)
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
 
     CHECK_FOR_DEFUNC( XAccessibleContext );
 
@@ -1015,7 +1015,7 @@ sal_Int32 SAL_CALL SwAccessibleContext::getBackground()
 OUString SAL_CALL SwAccessibleContext::getImplementationName()
         throw( uno::RuntimeException )
 {
-    ASSERT( !this, "implementation name needs to be overloaded" );
+    OSL_ENSURE( !this, "implementation name needs to be overloaded" );
 
     THROW_RUNTIME_EXCEPTION( lang::XServiceInfo, "implementation name needs to be overloaded" )
 }
@@ -1024,27 +1024,27 @@ sal_Bool SAL_CALL
     SwAccessibleContext::supportsService (const ::rtl::OUString& )
         throw (uno::RuntimeException)
 {
-    ASSERT( !this, "supports service needs to be overloaded" );
+    OSL_ENSURE( !this, "supports service needs to be overloaded" );
     THROW_RUNTIME_EXCEPTION( lang::XServiceInfo, "supports service needs to be overloaded" )
 }
 
 uno::Sequence< OUString > SAL_CALL SwAccessibleContext::getSupportedServiceNames()
         throw( uno::RuntimeException )
 {
-    ASSERT( !this, "supported services names needs to be overloaded" );
+    OSL_ENSURE( !this, "supported services names needs to be overloaded" );
     THROW_RUNTIME_EXCEPTION( lang::XServiceInfo, "supported services needs to be overloaded" )
 }
 
 void SwAccessibleContext::DisposeShape( const SdrObject *pObj,
                                 ::accessibility::AccessibleShape *pAccImpl )
 {
-    ::vos::ORef< ::accessibility::AccessibleShape > xAccImpl( pAccImpl );
-    if( !xAccImpl.isValid() )
+    ::rtl::Reference< ::accessibility::AccessibleShape > xAccImpl( pAccImpl );
+    if( !xAccImpl.is() )
         xAccImpl = GetMap()->GetContextImpl( pObj, this, sal_True );
 
     AccessibleEventObject aEvent;
     aEvent.EventId = AccessibleEventId::CHILD;
-    uno::Reference< XAccessible > xAcc( xAccImpl.getBodyPtr() );
+    uno::Reference< XAccessible > xAcc( xAccImpl.get() );
     aEvent.OldValue <<= xAcc;
     FireAccessibleEvent( aEvent );
 
@@ -1078,10 +1078,10 @@ void SwAccessibleContext::ScrolledInShape( const SdrObject* ,
 
 void SwAccessibleContext::Dispose( sal_Bool bRecursive )
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
 
-    ASSERT( GetFrm() && GetMap(), "already disposed" );
-    ASSERT( GetMap()->GetVisArea() == GetVisArea(),
+    OSL_ENSURE( GetFrm() && GetMap(), "already disposed" );
+    OSL_ENSURE( GetMap()->GetVisArea() == GetVisArea(),
                 "invalid vis area for dispose" );
 
     bDisposing = sal_True;
@@ -1109,7 +1109,7 @@ void SwAccessibleContext::Dispose( sal_Bool bRecursive )
     // set defunc state (its not required to broadcast a state changed
     // event if the object is diposed afterwards)
     {
-        vos::OGuard aDefuncStateGuard( aMutex );
+        osl::MutexGuard aDefuncStateGuard( aMutex );
         bIsDefuncState = sal_True;
     }
 
@@ -1131,7 +1131,7 @@ void SwAccessibleContext::Dispose( sal_Bool bRecursive )
 void SwAccessibleContext::DisposeChild( const SwAccessibleChild& rChildFrmOrObj,
                                         sal_Bool bRecursive )
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
 
     if ( IsShowing( *(GetMap()), rChildFrmOrObj ) ||
          rChildFrmOrObj.AlwaysIncludeAsChild() ||
@@ -1142,18 +1142,18 @@ void SwAccessibleContext::DisposeChild( const SwAccessibleChild& rChildFrmOrObj,
         // get notified of the movement.
         if( rChildFrmOrObj.GetSwFrm() )
         {
-            ::vos::ORef< SwAccessibleContext > xAccImpl =
+            ::rtl::Reference< SwAccessibleContext > xAccImpl =
                     GetMap()->GetContextImpl( rChildFrmOrObj.GetSwFrm(),
                                               sal_True );
             xAccImpl->Dispose( bRecursive );
         }
         else if ( rChildFrmOrObj.GetDrawObject() )
         {
-            ::vos::ORef< ::accessibility::AccessibleShape > xAccImpl =
+            ::rtl::Reference< ::accessibility::AccessibleShape > xAccImpl =
                     GetMap()->GetContextImpl( rChildFrmOrObj.GetDrawObject(),
                                               this, sal_True );
             DisposeShape( rChildFrmOrObj.GetDrawObject(),
-                          xAccImpl.getBodyPtr() );
+                          xAccImpl.get() );
         }
         else if ( rChildFrmOrObj.GetWindow() )
         {
@@ -1171,14 +1171,14 @@ void SwAccessibleContext::DisposeChild( const SwAccessibleChild& rChildFrmOrObj,
 
 void SwAccessibleContext::InvalidatePosOrSize( const SwRect& )
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
 
-    ASSERT( GetFrm() && !GetFrm()->Frm().IsEmpty(), "context should have a size" );
+    OSL_ENSURE( GetFrm() && !GetFrm()->Frm().IsEmpty(), "context should have a size" );
 
     sal_Bool bIsOldShowingState;
     sal_Bool bIsNewShowingState = IsShowing( *(GetMap()) );
     {
-        vos::OGuard aShowingStateGuard( aMutex );
+        osl::MutexGuard aShowingStateGuard( aMutex );
         bIsOldShowingState = bIsShowingState;
         bIsShowingState = bIsNewShowingState;
     }
@@ -1210,9 +1210,9 @@ void SwAccessibleContext::InvalidateChildPosOrSize(
                     const SwAccessibleChild& rChildFrmOrObj,
                     const SwRect& rOldFrm )
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
 
-    ASSERT( !rChildFrmOrObj.GetSwFrm() ||
+    OSL_ENSURE( !rChildFrmOrObj.GetSwFrm() ||
             !rChildFrmOrObj.GetSwFrm()->Frm().IsEmpty(),
             "child context should have a size" );
 
@@ -1235,26 +1235,25 @@ void SwAccessibleContext::InvalidateChildPosOrSize(
             if( rChildFrmOrObj.GetSwFrm() )
             {
                 // The frame becomes visible. A child event must be send.
-                ::vos::ORef< SwAccessibleContext > xAccImpl =
+                ::rtl::Reference< SwAccessibleContext > xAccImpl =
                     GetMap()->GetContextImpl( rChildFrmOrObj.GetSwFrm(),
                                               sal_True );
                 xAccImpl->ScrolledIn();
             }
             else if ( rChildFrmOrObj.GetDrawObject() )
             {
-                ::vos::ORef< ::accessibility::AccessibleShape > xAccImpl =
+                ::rtl::Reference< ::accessibility::AccessibleShape > xAccImpl =
                         GetMap()->GetContextImpl( rChildFrmOrObj.GetDrawObject(),
                                                   this, sal_True );
-                // --> OD 2004-11-29 #i37790#
-                if ( xAccImpl.isValid() )
+                // #i37790#
+                if ( xAccImpl.is() )
                 {
                     ScrolledInShape( rChildFrmOrObj.GetDrawObject(),
-                                     xAccImpl.getBodyPtr() );
+                                     xAccImpl.get() );
                 }
                 else
                 {
-                    ASSERT( false ,
-                            "<SwAccessibleContext::InvalidateChildPosOrSize(..)> - no accessible shape found." );
+                    OSL_FAIL( "<SwAccessibleContext::InvalidateChildPosOrSize(..)> - no accessible shape found." );
                 }
                 // <--
             }
@@ -1278,7 +1277,7 @@ void SwAccessibleContext::InvalidateChildPosOrSize(
         {
             if( rChildFrmOrObj.GetSwFrm() )
             {
-                ::vos::ORef< SwAccessibleContext > xAccImpl =
+                ::rtl::Reference< SwAccessibleContext > xAccImpl =
                     GetMap()->GetContextImpl( rChildFrmOrObj.GetSwFrm(),
                                               sal_True );
                 xAccImpl->SetParent( this );
@@ -1286,16 +1285,15 @@ void SwAccessibleContext::InvalidateChildPosOrSize(
             }
             else if ( rChildFrmOrObj.GetDrawObject() )
             {
-                ::vos::ORef< ::accessibility::AccessibleShape > xAccImpl =
+                ::rtl::Reference< ::accessibility::AccessibleShape > xAccImpl =
                         GetMap()->GetContextImpl( rChildFrmOrObj.GetDrawObject(),
                                                   this, sal_True );
                 DisposeShape( rChildFrmOrObj.GetDrawObject(),
-                          xAccImpl.getBodyPtr() );
+                          xAccImpl.get() );
             }
             else if ( rChildFrmOrObj.GetWindow() )
             {
-                ASSERT( false,
-                        "<SwAccessibleContext::InvalidateChildPosOrSize(..)> - not expected to handle dispose of child of type <Window>." );
+                OSL_FAIL( "<SwAccessibleContext::InvalidateChildPosOrSize(..)> - not expected to handle dispose of child of type <Window>." );
             }
         }
     }
@@ -1303,26 +1301,26 @@ void SwAccessibleContext::InvalidateChildPosOrSize(
 
 void SwAccessibleContext::InvalidateContent()
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
 
     _InvalidateContent( sal_False );
 }
 
 void SwAccessibleContext::InvalidateCursorPos()
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
 
     _InvalidateCursorPos();
 }
 
 void SwAccessibleContext::InvalidateFocus()
 {
-    vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
 
     _InvalidateFocus();
 }
 
-// --> OD 2005-12-12 #i27301# - use new type definition for <_nStates>
+// #i27301# - use new type definition for <_nStates>
 void SwAccessibleContext::InvalidateStates( tAccessibleStates _nStates )
 {
     if( GetMap() )
@@ -1335,7 +1333,7 @@ void SwAccessibleContext::InvalidateStates( tAccessibleStates _nStates )
                 sal_Bool bIsOldEditableState;
                 sal_Bool bIsNewEditableState = IsEditable( pVSh );
                 {
-                    vos::OGuard aGuard( aMutex );
+                    osl::MutexGuard aGuard( aMutex );
                     bIsOldEditableState = bIsEditableState;
                     bIsEditableState = bIsNewEditableState;
                 }
@@ -1349,7 +1347,7 @@ void SwAccessibleContext::InvalidateStates( tAccessibleStates _nStates )
                 sal_Bool bIsOldOpaqueState;
                 sal_Bool bIsNewOpaqueState = IsOpaque( pVSh );
                 {
-                    vos::OGuard aGuard( aMutex );
+                    osl::MutexGuard aGuard( aMutex );
                     bIsOldOpaqueState = bIsOpaqueState;
                     bIsOpaqueState = bIsNewOpaqueState;
                 }
@@ -1373,12 +1371,7 @@ void SwAccessibleContext::InvalidateRelation( sal_uInt16 nType )
     FireAccessibleEvent( aEvent );
 }
 
-/** text selection has changed
-
-    OD 2005-12-14 #i27301#
-
-    @author OD
-*/
+/** #i27301# - text selection has changed */
 void SwAccessibleContext::InvalidateTextSelection()
 {
     AccessibleEventObject aEvent;
@@ -1387,12 +1380,7 @@ void SwAccessibleContext::InvalidateTextSelection()
     FireAccessibleEvent( aEvent );
 }
 
-/** attributes has changed
-
-    OD 2009-01-06 #i88069#
-
-    @author OD
-*/
+/** #i88069# - attributes has changed */
 void SwAccessibleContext::InvalidateAttr()
 {
     AccessibleEventObject aEvent;
@@ -1459,7 +1447,7 @@ OUString SwAccessibleContext::GetResource( sal_uInt16 nResId,
 {
     String sStr;
     {
-        vos::OGuard aGuard(Application::GetSolarMutex());
+        SolarMutexGuard aGuard;
 
         sStr = SW_RES( nResId );
     }
@@ -1501,12 +1489,7 @@ bool SwAccessibleContext::HasAdditionalAccessibleChildren()
 
     return bRet;
 }
-/** get additional accessible child by index
-
-    OD 2010-01-27 #i88070#
-
-    @author OD
-*/
+/** #i88070# - get additional accessible child by index */
 Window* SwAccessibleContext::GetAdditionalAccessibleChild( const sal_Int32 nIndex )
 {
     Window* pAdditionalAccessibleChild( 0 );
@@ -1524,12 +1507,7 @@ Window* SwAccessibleContext::GetAdditionalAccessibleChild( const sal_Int32 nInde
     return pAdditionalAccessibleChild;
 }
 
-/** get all additional accessible children
-
-    OD 2010-01-27 #i88070#
-
-    @author OD
-*/
+/** #i88070# - get all additional accessible children */
 void SwAccessibleContext::GetAdditionalAccessibleChildren( std::vector< Window* >* pChildren )
 {
     if ( GetFrm()->IsTxtFrm() )
@@ -1602,3 +1580,5 @@ void lcl_SwAccessibleContext_DbgMsg( SwAccessibleContext *pThisAcc,
     aStrm.Flush();
 }
 #endif
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
